@@ -30,6 +30,7 @@ if six.PY2:
     class _PopenBase(subprocess.Popen):
         def __enter__(self):
             return self
+
         def __exit__(self, exc_type, value, traceback):
             self.wait()
 
@@ -134,9 +135,11 @@ def create_executable_script(filepath, body, program=None, py_script_mode=None):
     py_script_mode = py_script_mode or config.create_executable_script_mode
 
     # https://github.com/nerdvegas/rez/pull/968
-    is_forwarding_script_on_windows = (program == "_rez_fwd"
-                                       and platform_.name == "windows"
-                                       and filepath.lower().endswith(".cmd"))
+    is_forwarding_script_on_windows = (
+        program == "_rez_fwd"
+        and platform_.name == "windows"
+        and filepath.lower().endswith(".cmd")
+    )
 
     if callable(body):
         from rez.utils.sourcecode import SourceCode
@@ -180,8 +183,11 @@ def create_executable_script(filepath, body, program=None, py_script_mode=None):
         # clean up the files once the test has run.  Temporarily we don't bother
         # setting the permissions, but this will need to change.
         if os.name == "posix":
-            os.chmod(current_filepath, stat.S_IRUSR | stat.S_IRGRP | stat.S_IROTH
-                     | stat.S_IXUSR | stat.S_IXGRP | stat.S_IXOTH)
+            os.chmod(
+                current_filepath,
+                stat.S_IRUSR | stat.S_IRGRP | stat.S_IROTH | stat.S_IXUSR
+                | stat.S_IXGRP | stat.S_IXOTH
+            )
 
     return script_filepaths
 
@@ -205,20 +211,23 @@ def _get_python_script_files(filepath, py_script_mode, platform):
     has_py_ext = extension == ".py"
     is_windows = platform == "windows"
 
-    if py_script_mode == ExecutableScriptMode.single or \
-            py_script_mode == ExecutableScriptMode.both or \
-            (py_script_mode == ExecutableScriptMode.py and has_py_ext) or \
-            (py_script_mode == ExecutableScriptMode.platform_specific and
-             not is_windows) or \
-            (py_script_mode == ExecutableScriptMode.platform_specific and
-             is_windows and has_py_ext):
+    if (
+        py_script_mode == ExecutableScriptMode.single
+        or py_script_mode == ExecutableScriptMode.both
+        or (py_script_mode == ExecutableScriptMode.py and has_py_ext)
+        or (py_script_mode == ExecutableScriptMode.platform_specific and not is_windows)
+        or (py_script_mode == ExecutableScriptMode.platform_specific and is_windows and has_py_ext)
+    ):
         script_filepaths.append(filepath)
 
-    if not has_py_ext and \
-            ((py_script_mode == ExecutableScriptMode.both) or
-             (py_script_mode == ExecutableScriptMode.py) or
-             (py_script_mode == ExecutableScriptMode.platform_specific and
-              is_windows)):
+    if (
+        not has_py_ext
+        and (
+            py_script_mode == ExecutableScriptMode.both
+            or py_script_mode == ExecutableScriptMode.py
+            or (py_script_mode == ExecutableScriptMode.platform_specific and is_windows)
+        )
+    ):
         script_filepaths.append(base_filepath + ".py")
 
     return script_filepaths
@@ -233,8 +242,8 @@ def create_forwarding_script(filepath, module, func_name, *nargs, **kwargs):
     """
     from rez.utils.platform_ import platform_
 
-    if (platform_.name == "windows"
-            and os.path.splitext(filepath)[-1].lower() != ".cmd"):
+    if platform_.name == "windows" and \
+            os.path.splitext(filepath)[-1].lower() != ".cmd":
         filepath += ".cmd"
 
     doc = dict(
